<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="">
<xsl:output
   method="xml"
   indent="yes"
   encoding="iso-8859-1"
/>

<xsl:template match="normalizedMovies">
  <denormalizedMovies>
    <xsl:apply-templates select="movieIdTitle"/>
  </denormalizedMovies>
</xsl:template>

<xsl:template match="movieIdTitle/row">
  <xsl:variable name="rating" select="../../myTopMovies/row[@title_id=current()/@title_id]/@Rating"/>
  <movie id="{@title_id}" rating="{../../ratingLabels/row[@rating_id=$rating]/@rating_label}">
    <xsl:attribute name="year">
       <xsl:call-template name="outputYearFromTitle">
         <xsl:with-param name="titleString" select="@title"/>
       </xsl:call-template>
    </xsl:attribute>

    <title><xsl:value-of select="@title"/></title>
    <directors>
    	<xsl:apply-templates select="../../peopleMovies/row[@title_id=current()/@title_id and @role=0]"/>
    </directors>
    <actors>
    	<xsl:apply-templates select="../../peopleMovies/row[@title_id=current()/@title_id and @role=1]"/>
    </actors>
  </movie>
</xsl:template>

<xsl:template name="outputYearFromTitle">
  <!--  This template uses recursion to remove all, but the text inside the last parentheses.
        It should work fine on titles such as:
  Heaven Is What I've Done (For My Fellow Beings) (1984)
  Hollywood (and Vine) (1993)
  How to Save a Marriage (And Ruin Your Life) (1968)
  Slapstick (Of Another Kind) (1982)
  -->
  <xsl:param name="titleString"/>
  <xsl:choose>
    <xsl:when test="contains($titleString,'(')">
      <xsl:call-template name="outputYearFromTitle">
        <xsl:with-param name="titleString" select="substring-after($titleString, '(')"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="substring-before($titleString, ')')"/>    
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="peopleMovies/row">
  <xsl:choose>
    <xsl:when test="@role=0">
      <director id="{@name_id}"><xsl:value-of select="ancestor::normalizedMovies/peopleIdName/row[@name_id=current()/@name_id]/@name"/></director>
    </xsl:when>
    <xsl:when test="@role=1">
      <actor id="{@name_id}"><xsl:value-of select="ancestor::normalizedMovies/peopleIdName/row[@name_id=current()/@name_id]/@name"/></actor>
    </xsl:when>
  </xsl:choose>
</xsl:template>

<!--    BEGIN  Built-in templates -->
<xsl:template match="*|/">    <!-- Also for each existing mode. -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="text()|@*">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template match="processing-instruction()|comment()"/> 

<!--   END   Built-in templates -->

</xsl:stylesheet>
